@@ -260,14 +260,14 @@ WRITERS = {
 def write_data(encoder, datum, schema, named_schemas, fname):
     """Write a datum of data to output stream.
 
-    Paramaters
+    Parameters
     ----------
     encoder: encoder
         Type of encoder (e.g. binary or json)
     datum: object
         Data to write
     schema: dict
-        Schemda to use
+        Schema to use
     named_schemas: dict
         Mapping of fullname to schema definition
     """
@@ -367,7 +367,10 @@ else:
 
 def zstandard_write_block(encoder, block_bytes, compression_level):
     """Write block in "zstandard" codec."""
-    data = zstd.ZstdCompressor().compress(block_bytes)
+    if compression_level is not None:
+        data = zstd.ZstdCompressor(level=compression_level).compress(block_bytes)
+    else:
+        data = zstd.ZstdCompressor().compress(block_bytes)
     encoder.write_long(len(data))
     encoder._fo.write(data)
 
